@@ -1,24 +1,22 @@
 # -*- coding: utf-8 -*-
 from datetime import datetime
-from typing import Any, Optional, Sequence
 
+from django.conf import settings
 from django.contrib import admin
-from django.http import HttpRequest
+from django.forms import ModelForm, ValidationError
 from django.utils.translation import gettext_lazy as _
 
+from notifications.models import UserDevice
+
 from .models import (
-    Device,
-    DeviceSubscription,
     Notification,
-    NotificationTopic,
-    SentToDevice,
     UserNotification
 )
 
 
 @admin.register(UserNotification)
 class UserNotificationAdmin(admin.ModelAdmin):
-    actions = ['really_delete_selected']
+    actions = ['really_delete_selected', 'send_push_notifications']
 
     list_display = (
         'user',
@@ -49,16 +47,38 @@ class UserNotificationAdmin(admin.ModelAdmin):
             message_bit = "%s usernotification entries were" % queryset.count()
         self.message_user(request, "%s successfully deleted." % message_bit)
 
+    @admin.action(description=_('Send push notifications'))
+    def send_push_notifications(self, request, queryset):
+        for un in queryset.filter(notification__notification_type=Notification.TypeChoices.PUSH):
+            un.send_push_notification()
+
+
+class NotificationForm(ModelForm):
+    class Meta:
+        model = Notification
+        fields = '__all__'
+
+    def clean(self):
+        cleaned_data = super().clean()
+        is_push = cleaned_data.get('notification_type') == Notification.TypeChoices.PUSH
+        if is_push and not cleaned_data.get('topic'):
+            raise ValidationError({'topic': _('Push notifications must have a topic')})
+        return cleaned_data
+
 
 @admin.register(Notification)
 class NotificationAdmin(admin.ModelAdmin):
-    readonly_fields = ('management', 'aws_sns_id')
+    actions = ['send_push_notifications']
+    readonly_fields = ('management', )
     fields = (
         'name_en',
         'name_is',
         'message_en',
         'message_is',
+        'description_en',
+        'description_is',
         'notification_type',
+        'topic',
         'active_from',
         'expires',
         'needs_approval',
@@ -67,22 +87,23 @@ class NotificationAdmin(admin.ModelAdmin):
         'look',
         'image',
         'management',
-        'aws_sns_id',
-        'topic',
     )
     list_display = (
         'name',
         'notification_type',
+        'topic',
         'expires',
         'look',
         'needs_approval',
     )
+    list_filter = (
+        'notification_type',
+        'topic',
+        'look',
+        'needs_approval',
+    )
     ordering = ('-id', )
-
-    def has_change_permission(self, request: HttpRequest, obj: Optional[Notification] = None) -> Sequence[str]:
-        if obj is not None and obj.aws_sns_id:
-            return False
-        return super().has_change_permission(request, obj)
+    form = NotificationForm
 
     @admin.display(description='Management')
     def management(self, instance):
@@ -94,8 +115,6 @@ class NotificationAdmin(admin.ModelAdmin):
             'active_from',
             'snooze_lock',
             'recipients',
-            'send_email',
-            'aws_sns_id'
         ]
         params = ''
         for field in instance.__class__._meta.get_fields():
@@ -116,6 +135,11 @@ class NotificationAdmin(admin.ModelAdmin):
 
         return "python manage.py import_notification{}".format(params)
 
+    @admin.action(description=_('Send push notifications'))
+    def send_push_notifications(self, request, queryset):
+        for notification in queryset.filter(notification_type=Notification.TypeChoices.PUSH):
+            notification.send_push_notifications()
+
     def save_model(self, request, obj, form, change):
         super(NotificationAdmin, self).save_model(request, obj, form, change)
         for group in form.cleaned_data['groups']:
@@ -123,91 +147,21 @@ class NotificationAdmin(admin.ModelAdmin):
                 UserNotification.objects.get_or_create(notification=obj, user=user)
 
 
-class SentInline(admin.TabularInline):
-    model = SentToDevice
-    fields = ('notification', 'sent_at', 'get_sent', 'message_id')
-    readonly_fields = ('notification', 'sent_at', 'get_sent', 'message_id')
-    extra = 0
-    can_delete = False
-
-    def get_max_num(self, request: HttpRequest, obj: Optional[Notification] = None, **kwargs: Any) -> Optional[int]:
-        if obj is not None:
-            return obj.sent_notifications.count()
-        return super().get_max_num(request, obj, **kwargs)
-
-    def has_change_permission(self, *args, **kwargs) -> bool:
-        return False
-
-    @admin.display(description='Successfully sent')
-    def get_sent(self, obj):
-        return obj.sent
-
-
-@admin.register(Device)
-class DeviceAdmin(admin.ModelAdmin):
-    inlines = [SentInline]
+@admin.register(UserDevice)
+class UserDeviceAdmin(admin.ModelAdmin):
     list_display = (
         'user',
-        'os',
-        'token',
-        'arn',
+        'device_id',
+        'type',
         'active',
-        'created_at',
+        'name',
+        'date_created',
+        'registration_id',
     )
     readonly_fields = (
-        'arn',
-        'active',
-        'created_at',
-        'updated_at',
+        'user',
+        'device_id',
+        'type',
+        'date_created',
+        'registration_id',
     )
-
-    def get_actions(self, request):
-        actions = super().get_actions(request)
-        if 'delete_selected' in actions:
-            del actions['delete_selected']
-        return actions
-
-
-class NotificationInline(admin.TabularInline):
-    model = Notification
-    fields = ('name', 'message')
-    extra = 0
-    can_delete = False
-    show_change_link = True
-
-    def get_max_num(self, request: HttpRequest, obj: Optional[Notification] = None, **kwargs: Any) -> Optional[int]:
-        if obj is not None:
-            return obj.sent_notifications.count()
-        return super().get_max_num(request, obj, **kwargs)
-
-    def has_change_permission(self, *args, **kwargs) -> bool:
-        return False
-
-
-@admin.register(NotificationTopic)
-class NotificationTopicAdmin(admin.ModelAdmin):
-    inlines = [NotificationInline]
-    list_display = (
-        'name', 'language', 'arn', 'subscribed', 'sent'
-    )
-    readonly_fields = ('arn',)
-
-    def get_actions(self, request):
-        actions = super().get_actions(request)
-        if 'delete_selected' in actions:
-            del actions['delete_selected']
-        return actions
-
-    @admin.display(description='Subscribed')
-    def subscribed(self, obj):
-        return obj.subscriptions.count()
-
-    @admin.display(description='Sent notifications')
-    def sent(self, obj):
-        return obj.sent_notifications.count()
-
-
-@admin.register(DeviceSubscription)
-class DeviceSubscriptionAdmin(admin.ModelAdmin):
-    list_display = ('device_arn', 'topic', 'arn',)
-    readonly_fields = ('device_arn', 'topic', 'arn',)
