@@ -233,6 +233,7 @@ NotificationClient.prototype = {
   },
   dismissNotification: function (answer, answer_string) {
     var that = this;
+    var APIUrl = window.notificationEndpoint || '/api2/usernotifications/';  // Default in timon
     var request = this.setupRequest(function (request) {
       that.closeModal();
       setTimeout(function () {
@@ -241,7 +242,7 @@ NotificationClient.prototype = {
         }
       }, WAIT_UNTIL_NEXT_NOTIFICATION_MS);
     });
-    request.open('PATCH', '/api2/usernotifications/' + this.notification.id + '/');
+    request.open('PATCH', APIUrl + this.notification.id + '/');
     request.setRequestHeader('Content-Type', 'application/json;charset=UTF-8');
     request.setRequestHeader('X-CSRFToken', getCookie('csrftoken'));
     request.send(JSON.stringify({
@@ -259,7 +260,8 @@ NotificationClient.prototype = {
       }
     });
     var path = window.location.pathname;
-    request.open('GET', '/api2/usernotifications/?path=' + path);
+    var APIUrl = window.notificationEndpoint || '/api2/usernotifications/';  // Default in timon
+    request.open('GET', APIUrl + '?path=' + path);
     request.send();
   }
 };
